@@ -13,6 +13,7 @@ from .variants import variants as variants_command
 from .region import region as region_command
 from .user import user as user_command
 from .report import delivery_report as delivery_report_command
+from .report import cnv_report as cnv_report_command
 from .exons import exons as exons_command
 
 LOG = logging.getLogger(__name__)
@@ -33,4 +34,5 @@ load.add_command(user_command)
 load.add_command(research_command)
 load.add_command(variants_command)
 load.add_command(delivery_report_command)
+load.add_command(cnv_report_command)
 load.add_command(exons_command)
