@@ -14,7 +14,7 @@ clinical_snv_file = "demo/643594.clinical.vcf.gz"
 research_snv_file = "demo/643594.research.vcf.gz"
 customannotation_snv_file = "demo/customannotations_one.vcf.gz"
 vep_97_annotated_snv_file = "demo/vep97_annotated_clnsig_conservation_revel.vcf"
-manta_annotated_sv_cancer_file = "demo/manta_vep_94_annotated_sv_cancer_file.vcf"
+manta_annotated_sv_cancer_file = "demo/manta_vep_94_annotated_sv_cancer_file.vcf.gz"
 
 ped_path = pkg_resources.resource_filename("scout", ped_file)
 clinical_sv_file = "demo/643594.clinical.SV.vcf.gz"
