@@ -1,14 +1,12 @@
-# -*- coding: utf-8 -*-
+"""Code for panel gene form"""
 from flask_wtf import FlaskForm
-from wtforms import BooleanField, TextField, SelectMultipleField, TextField
+from wtforms import BooleanField, TextField, SelectMultipleField
 
 from scout.constants import GENE_CUSTOM_INHERITANCE_MODELS
 
 
 class PanelGeneForm(FlaskForm):
-    disease_associated_transcripts = SelectMultipleField(
-        "Disease transcripts", choices=[]
-    )
+    disease_associated_transcripts = SelectMultipleField("Disease transcripts", choices=[])
     reduced_penetrance = BooleanField()
     mosaicism = BooleanField()
     database_entry_version = TextField()
