@@ -5,6 +5,93 @@ from pymongo import IndexModel, ASCENDING
 from scout.commands import cli
 from scout.server.extensions import store
 
+VARIANTS_QUERY = {"rank_score": {"$lt": 15}}
+RANK_THRESHOLD = 15
+VARIANTS_THRESHOLD = 10
+
+
+def test_delete_variants_dry_run(mock_app, case_obj, user_obj):
+    """test command for cleaning variants collection - simulate deletion"""
+
+    assert store.user_collection.find_one()
+
+    # Given a database with SNV variants
+    runner = mock_app.test_cli_runner()
+    result = runner.invoke(
+        cli, ["load", "variants", case_obj["_id"], "--snv", "--rank-treshold", 5]
+    )
+    assert result.exit_code == 0
+    n_initial_vars = sum(1 for i in store.variant_collection.find())
+
+    # Then the function that delete variants in dry run should run without error
+    cmd_params = [
+        "delete",
+        "variants",
+        "-u",
+        user_obj["email"],
+        "-status",
+        "inactive",
+        "-older-than",
+        2,
+        "-rank-threshold",
+        RANK_THRESHOLD,
+        "-variants-threshold",
+        VARIANTS_THRESHOLD,
+        "--dry-run",
+    ]
+    result = runner.invoke(cli, cmd_params)
+    assert result.exit_code == 0
+    assert "estimated deleted variants" in result.output
+    assert "Estimated space freed" in result.output
+
+    # And no variants should be deleted
+    assert sum(1 for i in store.variant_collection.find()) == n_initial_vars
+
+
+def test_delete_variants(mock_app, case_obj, user_obj):
+    """Test deleting variants using the delete variants command line"""
+
+    # Given a database with SNV variants
+    runner = mock_app.test_cli_runner()
+    result = runner.invoke(
+        cli, ["load", "variants", case_obj["_id"], "--snv", "--rank-treshold", 5]
+    )
+    assert result.exit_code == 0
+    n_initial_vars = sum(1 for i in store.variant_collection.find())
+    n_variants_to_exclude = store.variant_collection.count_documents(VARIANTS_QUERY)
+
+    # Then the function that delete variants should run without error
+    cmd_params = [
+        "delete",
+        "variants",
+        "-u",
+        user_obj["email"],
+        "-status",
+        "inactive",
+        "-older-than",
+        2,
+        "-rank-threshold",
+        RANK_THRESHOLD,
+        "-variants-threshold",
+        VARIANTS_THRESHOLD,
+    ]
+    result = runner.invoke(cli, cmd_params, input="y")
+    assert result.exit_code == 0
+    assert "estimated deleted variants" not in result.output
+    assert "Estimated space freed" in result.output
+    # variants should be deleted
+    n_current_vars = sum(1 for i in store.variant_collection.find())
+    assert n_current_vars < n_initial_vars
+    assert n_current_vars + n_variants_to_exclude == n_initial_vars
+    # and a relative event should be created
+    event = store.event_collection.find_one()
+    assert event["verb"] == "remove_variants"
+    assert event["case"] == case_obj["_id"]
+    assert (
+        event["content"]
+        == f"Rank-score threshold:{RANK_THRESHOLD}, case n. variants threshold:{VARIANTS_THRESHOLD}."
+    )
+
 
 def test_delete_panel_non_existing(empty_mock_app, dummypanel_obj):
     "Test the CLI command that deletes a gene panel"
