@@ -8,7 +8,6 @@ import pymongo
 import pytest
 import yaml
 from cyvcf2 import VCF
-from flask_login import login_user, logout_user
 
 # Adapter stuff
 from mongomock import MongoClient
@@ -68,6 +67,7 @@ from scout.parse.panel import parse_gene_panel
 from scout.parse.variant import parse_variant
 from scout.parse.variant.headers import parse_rank_results_header
 from scout.server.blueprints.login.models import LoginUser
+from scout.server.app import create_app
 from scout.utils.handle import get_file_handle
 from scout.utils.link import link_genes
 
@@ -78,6 +78,22 @@ REAL_DATABASE = "realtestdb"
 # init_log(root_logger, loglevel='INFO')
 LOG = logging.getLogger(__name__)
 
+
+@pytest.fixture
+def mock_app(real_populated_database):
+    """Return the path to a mocked app object with data"""
+    _mock_app = create_app(
+        config=dict(
+            TESTING=True,
+            DEBUG=True,
+            MONGO_DBNAME=REAL_DATABASE,
+            DEBUG_TB_ENABLED=False,
+            LOGIN_DISABLED=True,
+        )
+    )
+    return _mock_app
+
+
 ##################### Gene fixtures #####################
 
 
@@ -1307,7 +1323,7 @@ def scout_config(request, config_file):
     """Return a dictionary with scout configs"""
     print("")
     in_handle = get_file_handle(config_file)
-    data = yaml.load(in_handle, Loader=yaml.FullLoader)
+    data = yaml.safe_load(in_handle)
     return data
 
 
@@ -1315,7 +1331,7 @@ def scout_config(request, config_file):
 def cancer_scout_config(request):
     """Return a dictionary with cancer case scout configs"""
     in_handle = get_file_handle(cancer_load_path)
-    data = yaml.load(in_handle, Loader=yaml.FullLoader)
+    data = yaml.safe_load(in_handle)
     return data
 
 
