@@ -4,6 +4,25 @@ import datetime
 import pytest
 
 
+@pytest.fixture
+def hpo_term(gene_list):
+    """A test HPO term"""
+    term = {
+        "_id": "HP:0001250",
+        "hpo_id": "HP:0001250",
+        "description": "Seizure",
+        "genes": gene_list,
+    }
+    return term
+
+
+@pytest.fixture
+def gene_list():
+    """A list of HGNC ids"""
+    gene_list = [26113, 9479, 10889, 18040, 10258]
+    return gene_list
+
+
 @pytest.fixture
 def panel():
     """Return a simple panel"""
