@@ -2,7 +2,59 @@
 from flask import Flask, url_for, Blueprint
 from scout.server.extensions import store
 import requests  # import requests for the purposes of monkeypatching
-from scout.server.blueprints.cases.controllers import case, case_report_content, mt_coverage_stats
+from scout.server.blueprints.cases.controllers import (
+    case,
+    case_report_content,
+    mt_coverage_stats,
+    phenotypes_genes,
+)
+
+
+def test_phenotypes_genes(gene_database, case_obj, hpo_term, gene_list):
+    """Test function that creates phenotype terms dictionaries with gene symbol info"""
+    adapter = gene_database
+    # Given a database with one phenotype term containing genes
+    assert adapter.hpo_term_collection.insert_one(hpo_term)
+
+    # And a case with that dynamic phenotype and gene list
+    case_obj["dynamic_panel_phenotypes"] = ["HP:0001250"]
+    case_obj["dynamic_gene_list"] = [{"hgnc_id": gene_id} for gene_id in gene_list]
+
+    # WHEN the phenotypes_genes is invoked providing test case
+    pheno_dict = phenotypes_genes(adapter, case_obj)
+
+    # THEN it should return a dictionary
+    # Containing the expected term
+    assert pheno_dict["HP:0001250"]["description"] == hpo_term["description"]
+    # And the expected genes
+    assert pheno_dict["HP:0001250"]["genes"]
+    # Coresponding of all HPO term genes
+    assert len(pheno_dict["HP:0001250"]["genes"].split(", ")) == len(hpo_term["genes"])
+
+
+def test_phenotype_genes_matching_phenotypes(gene_database, case_obj, hpo_term, gene_list):
+    """Test the function that creates the phenotype-genes terms dictionaries with genes matching more than 1 phenotype"""
+
+    adapter = gene_database
+    assert adapter.hgnc_collection.find_one()
+    # Given a database with 2 phenotype term containing matching genes
+
+    hpo_term2 = {
+        "_id": "HP:0001298",
+        "hpo_id": "HP:0001298",
+        "description": "Encephalopathy",
+        "genes": gene_list[2:],  # this term has last 3 genes overlapping with term 1
+    }
+    assert adapter.hpo_term_collection.insert([hpo_term, hpo_term2])
+    # And a case with that dynamic phenotype and gene list
+    case_obj["dynamic_panel_phenotypes"] = ["HP:0001250", "HP:0001298"]
+    case_obj["dynamic_gene_list"] = [{"hgnc_id": gene_id} for gene_id in gene_list[2:]]
+
+    # WHEN the phenotypes_genes is invoked providing test case
+    pheno_dict = phenotypes_genes(adapter, case_obj)
+
+    # THEN it should return a dictionary containing the 3 genes without associated HPO terms
+    assert len(pheno_dict["Analysed genes"]["genes"].split(", ")) == 3
 
 
 def test_coverage_stats(app, monkeypatch):
